==> pyams_content-0.3.0.tar.gz: pyams_content-0.3.0/src/pyams_content/shared/topic/manager.py <==
#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

from pyramid.events import subscriber
from zope.component.interfaces import ISite
from zope.interface import implementer
from zope.lifecycleevent.interfaces import IObjectAddedEvent
from zope.schema.fieldproperty import FieldProperty

from pyams_content.component.paragraph.interfaces import IParagraphFactorySettings
from pyams_content.component.theme.interfaces import IThemesManagerTarget
from pyams_content.reference.pictograms.interfaces import IPictogramManagerTarget
from pyams_content.shared.common.interfaces import ISharedContentFactory
from pyams_content.shared.common.manager import SharedTool
from pyams_content.shared.common.types import TypedSharedToolMixin
from pyams_content.shared.topic import Topic
from pyams_content.shared.topic.interfaces import ITopicManager, ITopicManagerFactory, \
    TOPIC_CONTENT_TYPE
from pyams_utils.adapter import adapter_config
from pyams_utils.registry import utility_config
from pyams_utils.traversing import get_parent


__docformat__ = 'restructuredtext'


@implementer(ITopicManager, IParagraphFactorySettings, IThemesManagerTarget, IPictogramManagerTarget)
class TopicManager(SharedTool, TypedSharedToolMixin):
    """Topic manager class"""

    shared_content_type = TOPIC_CONTENT_TYPE

    allowed_paragraphs = FieldProperty(IParagraphFactorySettings['allowed_paragraphs'])
    auto_created_paragraphs = FieldProperty(IParagraphFactorySettings['auto_created_paragraphs'])


@utility_config(provides=ITopicManagerFactory)
class TopicManagerFactory(object):
    """Default topic manager factory"""

    def __new__(cls):
        return TopicManager


@adapter_config(context=ITopicManager, provides=ISharedContentFactory)
def topic_manager_content_factory(context):
    return Topic


@subscriber(IObjectAddedEvent, context_selector=ITopicManager)
def handle_added_topic_manager(event):
    """Register topic manager when added"""
    site = get_parent(event.newParent, ISite)
    registry = site.getSiteManager()
    if registry is not None:
        registry.registerUtility(event.object, ITopicManager)

==> pyams_content-2.1.0.tar.gz: pyams_content-2.1.0/src/pyams_content/shared/topic/manager.py <==
#
# Copyright (c) 2015-2021 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

"""PyAMS_*** module

"""

__docformat__ = 'restructuredtext'

from pyramid.events import subscriber
from zope.component.interfaces import ISite
from zope.interface import implementer
from zope.lifecycleevent import IObjectAddedEvent

from pyams_content.component.paragraph.interfaces import IParagraphFactorySettingsTarget
from pyams_content.reference.pictogram.interfaces import IPictogramManagerTarget
from pyams_content.shared.common.manager import SharedTool
from pyams_content.shared.common.types import TypedSharedToolMixin
from pyams_content.shared.topic import TOPIC_CONTENT_TYPE
from pyams_content.shared.topic.interfaces import ITopicManager
from pyams_utils.factory import factory_config
from pyams_utils.traversing import get_parent


@factory_config(ITopicManager)
@implementer(IParagraphFactorySettingsTarget, IPictogramManagerTarget)
class TopicManager(SharedTool, TypedSharedToolMixin):
    """Topic manager class"""

    shared_content_type = TOPIC_CONTENT_TYPE


@subscriber(IObjectAddedEvent, context_selector=ITopicManager)
def handle_added_topic_manager(event):
    """Register topic manager when added"""
    site = get_parent(event.newParent, ISite)
    registry = site.getSiteManager()
    if registry is not None:
        registry.registerUtility(event.object, ITopicManager)
